# Build Information

_provided by [glsr-present](https://pypi.org/project/glsr-present/) 0.3.6_

[ncw](https://gitlab.com/blackstream-x/ncw)
built with pipeline
[1841389352](https://gitlab.com/blackstream-x/ncw/-/pipelines/1841389352)
(build started 2025-05-28T16:15:10Z)

